/*
* Copyright 2004 - 2009 by dronten@gmail.com
*
* This source is distributed under the terms of the GNU PUBLIC LICENSE version 3
* http://www.gnu.org/licenses/gpl.html
*/

package com.googlepages.dronten.jtagger.gui;

import com.googlepages.dronten.jtagger.gui.albumtab.AlbumSplitPane;
import com.googlepages.dronten.jtagger.gui.filenametab.FileSplitPane;
import com.googlepages.dronten.jtagger.gui.leftpanel.LeftPanel;
import com.googlepages.dronten.jtagger.gui.titletab.TitleSplitPane;
import com.googlepages.dronten.jtagger.gui.tracktab.TrackSplitPane;

import javax.swing.*;
import java.awt.*;


/**
 * Main window object with all gui panels.<br>
 * It is owned my JTagger (JFrame) object
 */
public class MainWindow extends JPanel {
    private static final long   serialVersionUID = 1;
    private JSplitPane          aSplitPane = null;
    private LeftPanel           aLeftPanel = null;
    private JTabbedPane         aCenterPanel = null;
    private StatusBar           aStatusBar = null;

    private TrackSplitPane      aTrackPane = null;
    private FileSplitPane       aFilePane = null;
    private AlbumSplitPane      aAlbumPane = null;
    private TitleSplitPane      aTitlePane = null;


    /**
     * Create main application window.
     */
    public MainWindow() {
    }


    /**
     * Create GUI.
     */
    public void create() {
        aSplitPane = new JSplitPane();
        aLeftPanel = new LeftPanel();
        aCenterPanel = new JTabbedPane();
        aStatusBar = new StatusBar();

        setLayout(new BorderLayout());
        aSplitPane.setLeftComponent(aLeftPanel);
        aSplitPane.setRightComponent(aCenterPanel);
        add(aSplitPane, BorderLayout.CENTER);
        add(aStatusBar, BorderLayout.SOUTH);
        aTrackPane = new TrackSplitPane();
        aFilePane = new FileSplitPane();
        aAlbumPane = new AlbumSplitPane();
        aTitlePane = new TitleSplitPane();

        aCenterPanel.setBorder(BorderFactory.createEmptyBorder(5, 3, 5, 3));
        aCenterPanel.addTab("Audio Files", null, aTrackPane, "View and edit audio files in current selected directory");
        aCenterPanel.addTab("Rename Files", null, aFilePane, "Batch rename audio files from current selected directory");
        aCenterPanel.addTab("Rename Album Tags", null, aAlbumPane, "Batch update album tags for Audio files from current selected directory");
        aCenterPanel.addTab("Rename Title Tags", null, aTitlePane, "Batch update title tags for Audio files from current selected directory");
    }


    /**
     *
     * @return
     */
    public LeftPanel getLeftPanel() {
        return aLeftPanel;
    }


    /**
     *
     * @return
     */
    public JTabbedPane getCenterPanel() {
        return aCenterPanel;
    }


    /**
     *
     * @return
     */
    public StatusBar getStatusBar() {
        return aStatusBar;
    }


    /**
     *
     * @return
     */
    public JSplitPane getSplitPane() {
        return aSplitPane;
    }


    /**
     *
     * @return
     */
    public TrackSplitPane getTrackPane() {
        return aTrackPane;
    }


    /**
     *
     * @return
     */
    public FileSplitPane getFilePane() {
        return aFilePane;
    }


    /**
     *
     * @return
     */
    public AlbumSplitPane getAlbumPane() {
        return aAlbumPane;
    }


    /**
     *
     * @return
     */
    public TitleSplitPane getTitlePane() {
        return aTitlePane;
    }
}
