/*
* Copyright 2004 - 2009 by dronten@gmail.com
*
* This source is distributed under the terms of the GNU PUBLIC LICENSE version 3
* http://www.gnu.org/licenses/gpl.html
*/

package com.googlepages.dronten.jtagger.gui.dlg;

import com.googlepages.dronten.jtagger.gui.ComponentFactory;

import javax.swing.*;
import javax.swing.text.html.HTMLEditorKit;
import java.awt.*;
import java.awt.event.ActionEvent;
import java.awt.event.ActionListener;


/**
 * A html message dialog object.
 */
public class MessageDialog extends BaseDialog implements ActionListener {
    private static final long   serialVersionUID = 1;
    private JEditorPane         aEditor = null;


    /**
     * Create help dialog.
     *
     * @param owner         Set to null to create a window that can hide below application.
     * @param title         Dialog title
     * @param close_text    Close button text
     * @throws HeadlessException
     */
    public MessageDialog(JFrame owner, String title, String close_text) throws HeadlessException {
        super(owner, title, false);

        aEditor = new JEditorPane();
        JButton close = ComponentFactory.createButton(close_text, "", this, 0, 0);
        JScrollPane editScrollPane = new JScrollPane(aEditor);
        JPanel mainPanel = new JPanel();

        aEditor.setEditable(false);
        mainPanel.setLayout(ComponentFactory.createBorderLayout(5, 5));
        mainPanel.setBorder(BorderFactory.createEmptyBorder(5, 5, 5, 5));
        mainPanel.setPreferredSize(new Dimension(700, 500));
        mainPanel.setMaximumSize(new Dimension(2000, 2000));

        mainPanel.add(editScrollPane, BorderLayout.CENTER);
        mainPanel.add(close, BorderLayout.SOUTH);
        setContentPane(mainPanel);
        pack();
    }


    /**
     * @param actionEvent
     */
    @Override public void actionPerformed(ActionEvent actionEvent) {
        setVisible(false);
    }


    /**
     * Set text in html format.
     *
     * @param html HTML
     */
    public void setHtml(String html) {
        aEditor.setEditorKit(new HTMLEditorKit());
        aEditor.setText(html);
        aEditor.setCaretPosition(0);
    }


    /**
     * Set plain text.
     *
     * @param text Text
     */
    public void setText(String text) {
        aEditor.setText(text);
    }
}