/*
* Copyright 2004 - 2009 by dronten@gmail.com
*
* This source is distributed under the terms of the GNU PUBLIC LICENSE version 3
* http://www.gnu.org/licenses/gpl.html
*/

package com.googlepages.dronten.jtagger.gui.dlg.setup;

import com.googlepages.dronten.jtagger.Constants;
import com.googlepages.dronten.jtagger.JTagger;
import com.googlepages.dronten.jtagger.gui.ComponentFactory;
import com.googlepages.dronten.jtagger.util.Pref;

import javax.swing.*;
import java.awt.*;
import java.awt.event.ActionEvent;
import java.awt.event.ActionListener;


/**
 * Set general preferences.
 */
public class GeneralSetup extends BaseSetup implements ActionListener {
    private static final long   serialVersionUID = 1;
    private JCheckBox           aStartFromLast = null;
    private JTextField          aStartDir = null;
    private JTextField          aCodepage = null;
    private JButton             aBrowseDir = null;


    /**
     *
     */
    public GeneralSetup() {
        super();

        aStartFromLast = ComponentFactory.createCheck(Pref.getPref(Constants.PREF_STARTFROMLAST, "YES").length() > 0, "Start from last selected directory", "Check to start from the same directory you last visited last time you did run jTagger", 0, 0);
        aStartDir = ComponentFactory.createInput(Pref.getPref(Constants.PREF_STARTDIR, ""), "<html>Enter start directory and uncheck <b>Start directory</b><br>to always start the program from this directory.</html>", 0, 0);
        aBrowseDir = ComponentFactory.createButton("&>>", "Browse and select directory", this, 0, 0);
        aCodepage = ComponentFactory.createInput(Pref.getPref(Constants.CODEPAGE, ""), "<html>Set character codepage if tags are not displayed properly(experimental).</html>", 0, 0);

        add(Box.createRigidArea(new Dimension(0, 5)));
        add(ComponentFactory.createOnePanel(aStartFromLast));
        add(Box.createRigidArea(new Dimension(0, 5)));
        add(ComponentFactory.createThreePanel(new JLabel("Startup directory"), aStartDir, aBrowseDir));
    }


    /**
     * @param actionEvent
     */
    @Override public void actionPerformed(ActionEvent actionEvent) {
        if (actionEvent.getSource() == aBrowseDir) {
            JFileChooser chooser = new JFileChooser();

            chooser.setFileSelectionMode(JFileChooser.DIRECTORIES_ONLY);
            chooser.setDialogTitle("Select Directory");

            if (chooser.showOpenDialog(JTagger.get()) == JFileChooser.APPROVE_OPTION) {
                aStartDir.setText(chooser.getSelectedFile().getPath());
            }
        }
    }


    /**
     * Save settings.
     */
    @Override public void save() {
        try {
            Pref.setPref(Constants.PREF_STARTFROMLAST, aStartFromLast.isSelected() ? "YES" : "");
            Pref.setPref(Constants.PREF_STARTDIR, aStartDir.getText());
            JTagger.get().setCodePage(aCodepage.getText());

        }
        catch (Exception e) {
            if (Constants.DEBUG) e.printStackTrace();
        }
    }
}
