/*
* Copyright 2004 - 2009 by dronten@gmail.com
*
* This source is distributed under the terms of the GNU PUBLIC LICENSE version 3
* http://www.gnu.org/licenses/gpl.html
*/

package com.googlepages.dronten.jtagger.gui.dlg.setup;

import com.googlepages.dronten.jtagger.gui.ComponentFactory;
import com.googlepages.dronten.jtagger.gui.dlg.BaseDialog;

import javax.swing.*;
import javax.swing.event.ListSelectionEvent;
import javax.swing.event.ListSelectionListener;
import java.awt.*;
import java.awt.event.ActionEvent;
import java.awt.event.ActionListener;


/**
 * A preference dialog.
 */
public class SetupDialog extends BaseDialog implements ActionListener, ListSelectionListener {
    private static final long   serialVersionUID = 1;
    private JPanel              aSetupPanel = null;
    private JList               aList = null;
    private BaseSetup[]         aSetupPanels = null;
    private BaseSetup           aCurrentSetup = null;


    /**
     * Create setup dialog.
     *
     * @param owner         Dialog owner
     * @param titleText     Dialog title
     * @param closeText     Close button text
     * @param choices       Choice labels as an array of strings
     * @param panels        Child panels
     * @throws HeadlessException
     */
    public SetupDialog(JFrame owner, String titleText, String closeText, String[] choices, BaseSetup[] panels) throws HeadlessException {
        super(owner, titleText, true);
        aSetupPanels = panels;
        aList = new JList(choices);
        aSetupPanel = new JPanel();

        JButton     closeButton = ComponentFactory.createButton(closeText, "", this, 0, 0);
        JScrollPane scrollPaneList = new JScrollPane();
        JPanel      mainPanel = new JPanel();

        for (BaseSetup panel : aSetupPanels) {
            panel.setVisible(false);
        }

        aList.addListSelectionListener(this);
        scrollPaneList.getViewport().setView(aList);
        aSetupPanel.setLayout(ComponentFactory.createBorderLayout(5, 5));
        mainPanel.setLayout(ComponentFactory.createBorderLayout(5, 5));
        mainPanel.setBorder(BorderFactory.createEmptyBorder(5, 5, 5, 5));

        mainPanel.add(scrollPaneList, BorderLayout.WEST);
        mainPanel.add(aSetupPanel, BorderLayout.CENTER);
        mainPanel.add(closeButton, BorderLayout.SOUTH);

        setPreferredSize(new Dimension(600, 600));
        setMaximumSize(new Dimension(2000, 2000));
        setContentPane(mainPanel);
        pack();
        aList.setSelectedIndex(0);
    }


    /**
     * Let all child panels save them self before quitting.
     *
     * @param actionEvent
     */
    @Override public void actionPerformed(ActionEvent actionEvent) {
        for (BaseSetup panel : aSetupPanels) {
            panel.save();
        }
        setVisible(false);
    }


    /**
     * @param listSelectionEvent
     */
    @Override public void valueChanged(ListSelectionEvent listSelectionEvent) {
        int index = aList.getSelectedIndex();

        if (aCurrentSetup != null) {
            aCurrentSetup.setVisible(false);
            aCurrentSetup = null;
        }

        if (index < aSetupPanels.length) {
            aCurrentSetup = aSetupPanels[index];
            aCurrentSetup.setVisible(true);
            aSetupPanel.add(aCurrentSetup, BorderLayout.NORTH);
            pack();
        }
    }
}
