/*
* Copyright 2004 - 2009 by dronten@gmail.com
*
* This source is distributed under the terms of the GNU PUBLIC LICENSE version 3
* http://www.gnu.org/licenses/gpl.html
*/

package com.googlepages.dronten.jtagger.gui.titletab;

import com.googlepages.dronten.jtagger.Constants;
import com.googlepages.dronten.jtagger.gui.ComponentFactory;
import com.googlepages.dronten.jtagger.renamer.TitleRenamer;

import javax.swing.*;
import java.awt.*;
import java.awt.event.ActionEvent;
import java.awt.event.ActionListener;


/**
 * Display rename album options.
 */
public class TitleOptionsPanel extends JPanel implements ActionListener {
    private static final long   serialVersionUID = 1;
    private JCheckBox           aUseFileName;
    private JCheckBox           aTitle;
    private JTextField          aTitleInput;
    private JCheckBox           aRemoveLeading;
    private JCheckBox           aRemoveTrailing;
    private JCheckBox           aRemoveText;
    private JTextField          aRemoveTextInput;
    private JCheckBox           aReplaceText;
    private JTextField          aReplaceTextInput;
    private JCheckBox           aInsertText;
    private JTextField          aInsertTextInput;
    private JCheckBox           aAppendText;
    private JTextField          aAppendTextInput;
    private JComboBox           aCapitalize;
    private JRadioButton        aNumber0;
    private JRadioButton        aNumber1;
    private JRadioButton        aNumber2;
    private JRadioButton        aNumber3;
    private JRadioButton        aNumber4;
    private JTextField          aStartNumber2;
    private JTextField          aStartNumber4;
    private JTextField          aNumberSizeText;
    private JTextField          aNumberSeparator;


    /**
     * Create title rename options panel.<br>
     * All gui options for renaming track titles are here.
     */
    public TitleOptionsPanel() {
        super();
        JPanel top = new JPanel();
        JPanel bottom = new JPanel();

        top.setLayout(new BoxLayout(top, BoxLayout.Y_AXIS));
        bottom.setLayout(new BoxLayout(bottom, BoxLayout.Y_AXIS));

        setLayout(new BorderLayout());
        setBorder(BorderFactory.createEmptyBorder(5, 5, 5, 5));

        /*********************************************************************/

        aUseFileName = ComponentFactory.createCheck(false, "Use Filename", "Use filename as the track title");
        top.add(ComponentFactory.createOnePanel(aUseFileName));
        top.add(Box.createRigidArea(new Dimension(0, 2)));

        aTitle = ComponentFactory.createCheck(false, "Set Title", "Enter title text");
        aTitleInput = ComponentFactory.createInput("", "Enter title");
        top.add(ComponentFactory.createTwoPanel(aTitle, aTitleInput));
        top.add(Box.createRigidArea(new Dimension(0, 2)));

        aRemoveLeading = ComponentFactory.createCheck(false, "Remove Leading", "Remove all leading none letters from the title until first letter is found");
        top.add(ComponentFactory.createOnePanel(aRemoveLeading));
        top.add(Box.createRigidArea(new Dimension(0, 2)));

        aRemoveTrailing = ComponentFactory.createCheck(false, "Remove Trailing", "Remove all trailing none letters from the title");
        top.add(ComponentFactory.createOnePanel(aRemoveTrailing));
        top.add(Box.createRigidArea(new Dimension(0, 2)));

        aRemoveText = ComponentFactory.createCheck(false, "Remove Text", "<html>Enter text to remove from the title<br>Try regular expressions such ' - \\d* of \\d*' which removes text like ' - 09 of 12'</html>");
        aRemoveTextInput = ComponentFactory.createInput("", "");
        top.add(ComponentFactory.createTwoPanel(aRemoveText, aRemoveTextInput));
        top.add(Box.createRigidArea(new Dimension(0, 2)));

        aReplaceText = ComponentFactory.createCheck(false, "Replace Text", "Enter text to replace removed text");
        aReplaceTextInput = ComponentFactory.createInput("", "");
        top.add(ComponentFactory.createTwoPanel(aReplaceText, aReplaceTextInput));
        top.add(Box.createRigidArea(new Dimension(0, 2)));

        aInsertText = ComponentFactory.createCheck(false, "Insert Text", "Enter text to insert before title");
        aInsertTextInput = ComponentFactory.createInput("", "");
        top.add(ComponentFactory.createTwoPanel(aInsertText, aInsertTextInput));
        top.add(Box.createRigidArea(new Dimension(0, 2)));

        aAppendText = ComponentFactory.createCheck(false, "Append Text", "Enter text to append after title");
        aAppendTextInput = ComponentFactory.createInput("", "");
        top.add(ComponentFactory.createTwoPanel(aAppendText, aAppendTextInput));
        top.add(Box.createRigidArea(new Dimension(0, 2)));

        /*********************************************************************/

        top.add(Box.createRigidArea(new Dimension(0, 10)));
        top.add(new JSeparator());
        top.add(Box.createRigidArea(new Dimension(0, 10)));

        /*********************************************************************/

        aNumber0 = ComponentFactory.createRadio(true, "Don't Insert Track Number", "");
        top.add(ComponentFactory.createOnePanel(aNumber0));
        top.add(Box.createRigidArea(new Dimension(0, 3)));

        aNumber1 = ComponentFactory.createRadio(false, "Insert Track Number", "<html>Insert track number from the album first in title</html>");
        top.add(ComponentFactory.createOnePanel(aNumber1));
        top.add(Box.createRigidArea(new Dimension(0, 3)));

        aNumber2 = ComponentFactory.createRadio(false, "Insert Number", "<html>Insert track number first in title<br>Enter start track number<br>Default start track is 1</html>");
        aStartNumber2 = ComponentFactory.createInput("1", "");
        top.add(ComponentFactory.createTwoPanel(aNumber2, aStartNumber2));
        top.add(Box.createRigidArea(new Dimension(0, 3)));

        aNumber3 = ComponentFactory.createRadio(false, "Append Track Number", "<html>Append track number from the track last in the filename</html>");
        top.add(ComponentFactory.createOnePanel(aNumber3));
        top.add(Box.createRigidArea(new Dimension(0, 3)));

        aNumber4 = ComponentFactory.createRadio(false, "Append Number", "<html>Append track number last in the filename<br>Enter start track number<br>Default start track is 1</html>");
        aStartNumber4 = ComponentFactory.createInput("1", "");
        top.add(ComponentFactory.createTwoPanel(aNumber4, aStartNumber4));
        top.add(Box.createRigidArea(new Dimension(0, 3)));

        ButtonGroup group = new ButtonGroup();
        group.add(aNumber0);
        group.add(aNumber1);
        group.add(aNumber2);
        group.add(aNumber3);
        group.add(aNumber4);

        JLabel label = ComponentFactory.createLabel("Number Size", "<html>Number of numerals in the track number<br>Enter a number between 0 and 6</html>");
        aNumberSizeText = ComponentFactory.createInput("2", "");
        top.add(ComponentFactory.createTwoPanel(label, aNumberSizeText));
        top.add(Box.createRigidArea(new Dimension(0, 3)));

        label = ComponentFactory.createLabel("Number Separator", "<html>Separator string to insert between track number and the title<br>Default separator is space</html>");
        aNumberSeparator = ComponentFactory.createInput(" ", "");
        top.add(ComponentFactory.createTwoPanel(label, aNumberSeparator));

        /*********************************************************************/

        top.add(Box.createRigidArea(new Dimension(0, 10)));
        top.add(new JSeparator());
        top.add(Box.createRigidArea(new Dimension(0, 10)));

        /*********************************************************************/

        aCapitalize = ComponentFactory.createCombo(Constants.OPTIONS_CAP_TITLE, 0, "Change Title Capitalisation", 0, 0);
        top.add(ComponentFactory.createOnePanel(aCapitalize));
        top.add(Box.createRigidArea(new Dimension(0, 2)));

        /*********************************************************************/

        JButton button = ComponentFactory.createButton("Reset &Options", "Reset and clear all options", this);
        bottom.add(button);

        /*********************************************************************/

        add(top, BorderLayout.NORTH);
        add(bottom, BorderLayout.SOUTH);

        setMinimumSize(new Dimension(150, Short.MAX_VALUE));
        setPreferredSize(new Dimension(250, Short.MAX_VALUE));
    }


    /**
     * Reset options.
     *
     * @param actionEvent
     */
    public void actionPerformed(ActionEvent actionEvent) {
        aUseFileName.setSelected(false);
        aTitle.setSelected(false);
        aTitleInput.setText("");
        aRemoveLeading.setSelected(false);
        aRemoveTrailing.setSelected(false);
        aRemoveText.setSelected(false);
        aRemoveTextInput.setText("");
        aReplaceText.setSelected(false);
        aReplaceTextInput.setText("");
        aInsertText.setSelected(false);
        aInsertTextInput.setText("");
        aAppendText.setSelected(false);
        aAppendTextInput.setText("");
        aCapitalize.setSelectedIndex(0);
        aNumber0.setSelected(true);
        aStartNumber2.setText("1");
        aStartNumber4.setText("1");
        aNumberSizeText.setText("2");
        aNumberSeparator.setText(" ");
    }


    /**
     * Create renamer object with all options set.
     *
     * @return FileRenamer object.
     */
    public TitleRenamer getRenamer() {
        TitleRenamer renamer = new TitleRenamer();

        if (aUseFileName.isSelected()) {
            renamer.aUseFileName = "YES";
        }

        if (aTitle.isSelected()) {
            renamer.aUseTitle = aTitleInput.getText();
        }

        if (aRemoveLeading.isSelected()) {
            renamer.aRemoveLeading = "YES";
        }

        if (aRemoveTrailing.isSelected()) {
            renamer.aRemoveTrailing = "YES";
        }

        if (aRemoveText.isSelected()) {
            renamer.aRemoveText = aRemoveTextInput.getText();
        }

        if (aReplaceText.isSelected()) {
            renamer.aReplaceText = aReplaceTextInput.getText();
        }

        if (aInsertText.isSelected()) {
            renamer.aInsertText = aInsertTextInput.getText();
        }

        if (aAppendText.isSelected()) {
            renamer.aAppendText = aAppendTextInput.getText();
        }

        if (aNumber1.isSelected()) {
            renamer.aNumber = 1;
        }
        else if (aNumber2.isSelected()) {
            renamer.aNumber = 2;
            renamer.aStartNumber = aStartNumber2.getText();
        }
        else if (aNumber3.isSelected()) {
            renamer.aNumber = 3;
        }
        else if (aNumber4.isSelected()) {
            renamer.aNumber = 4;
            renamer.aStartNumber = aStartNumber4.getText();
        }

        renamer.aNumberSize = aNumberSizeText.getText();
        renamer.aNumberSeparator = aNumberSeparator.getText();
        renamer.aCapitalize = aCapitalize.getSelectedIndex();

        return renamer;
    }
}
