/*
* Copyright 2004 - 2009 by dronten@gmail.com
*
* This source is distributed under the terms of the GNU PUBLIC LICENSE version 3
* http://www.gnu.org/licenses/gpl.html
*/

package com.googlepages.dronten.jtagger.model;

import com.googlepages.dronten.jtagger.Constants;
import com.googlepages.dronten.jtagger.JTagger;
import com.googlepages.dronten.jtagger.audio.AudioTrack;
import com.googlepages.dronten.jtagger.audio.AudioTrackComparator;
import com.googlepages.dronten.jtagger.gui.dlg.ProgressDialog;
import com.googlepages.dronten.jtagger.renamer.FileRenamer;
import com.googlepages.dronten.jtagger.thread.AudioThread;
import com.googlepages.dronten.jtagger.thread.BaseThread;
import com.googlepages.dronten.jtagger.thread.BatchWorkThread;
import com.googlepages.dronten.jtagger.util.Log;
import com.googlepages.dronten.jtagger.util.Progress;

import javax.swing.table.AbstractTableModel;
import javax.swing.table.JTableHeader;
import javax.swing.table.TableColumnModel;
import java.awt.event.ActionEvent;
import java.awt.event.ActionListener;
import java.awt.event.MouseAdapter;
import java.awt.event.MouseEvent;


/**
 * FileModel uses mp3 model from the only instance of TrackModel that exist.
 */
public class FileModel extends AbstractTableModel implements ActionListener {
    private static final long   serialVersionUID = 1;
    public MouseHandler         aMouseHandler;


    /**
     * Singleton object.
     */
    public FileModel() {
        aMouseHandler = new MouseHandler();
    }


    /**
     * Button callback.
     *
     * @param event Action event
     */
    @Override public void actionPerformed(ActionEvent event) {
        if (event.getSource() == JTagger.get().getMainWindow().getFilePane().getFileTable().aTestRenameButton) {
            try {
                FileRenamer renamer = JTagger.get().getMainWindow().getFilePane().getFileOptionsPanel().getRenamer();

                JTagger.get().getMainWindow().getTrackPane().getTrackTable().getTrackModel().startTest();
                for (AudioTrack track : JTagger.get().getMainWindow().getTrackPane().getTrackTable().getTrackModel().getTestAudioTracks()) {
                    if (track.isSelected()) {
                        renamer.rename(track);
                    }
                }

                JTagger.get().setMessage(Constants.MESSAGE_TEST_OK, false);
                JTagger.get().reloadAllTables();
            }
            catch (Exception e) {
                Log.get().addTime(1, e.getMessage());
                JTagger.get().setMessage(e.getMessage(), true);
                JTagger.get().reloadAllTables();
            }
        }
        else if (event.getSource() == JTagger.get().getMainWindow().getFilePane().getFileTable().aUndoTestButton) {
            JTagger.get().setMessage(Constants.MESSAGE_TEST_UNDONE, false);
            JTagger.get().getMainWindow().getTrackPane().getTrackTable().getTrackModel().clearTest();
            JTagger.get().reloadAllTables();
        }
        else if (event.getSource() == JTagger.get().getMainWindow().getFilePane().getFileTable().aUpdateButton) {
            try {
                AudioThread.get().throwIfPlaying();

                ProgressDialog  dlg = new ProgressDialog(JTagger.get(), "Renaming Files", "Cancel", true);
                BaseThread      work = new BatchWorkThread(Log.get(), Progress.get(), JTagger.get().getMainWindow().getFilePane().getFileOptionsPanel().getRenamer());

                dlg.centerOnApplication();
                dlg.show(work);
                work.join();
                JTagger.get().reloadAllTables();
            }
            catch (Exception e) {
                Log.get().addTime(1, e.getMessage());
                JTagger.get().setMessage(e.getMessage(), true);
                JTagger.get().reloadAllTables();
            }
        }
        else {
            assert false;
        }
    }


    /**
     * @param column
     * @return Column class
     */
    @Override public Class getColumnClass(int column) {
        switch (column) {
            case 0:
                return Boolean.class;

            case 1:
                return Integer.class;

            default:
                return String.class;
        }
    }


    /**
     * @return Number of columns
     */
    @Override public int getColumnCount() {
        return 3;
    }


    /**
     * @param col
     * @return Column label
     */
    @Override public String getColumnName(int col) {
        switch (col) {
            case 0:
                return "Select";

            case 1:
                return "Track";

            default:
                return "File";
        }
    }


    /**
     * @return Number of rows
     */
    @Override public int getRowCount() {
        return JTagger.get().getMainWindow().getTrackPane().getTrackTable().getTrackModel().getRowCount();
    }


    /**
     * @param row
     * @param col
     * @return Object to paint in cell
     */
    @Override public Object getValueAt(int row, int col) {
        AudioTrack track = JTagger.get().getMainWindow().getTrackPane().getTrackTable().getTrackModel().getTrack(row);
        AudioTrack testTrack = JTagger.get().getMainWindow().getTrackPane().getTrackTable().getTrackModel().getTestTrack(row);

        try {
            if (track != null) {
                if (col == 0) {
                    return track.isSelected();
                }
                else if (col == 1) {
                    if (testTrack != null) {
                        return testTrack.aTrack;
                    }
                    else {
                        return track.aTrack;
                    }
                }
                else  if (col == 2) {
                    if (testTrack != null) {
                        return testTrack.aFileName;
                    }
                    else {
                        return track.aFileName;
                    }
                }
            }
        }
        catch (Exception e) {
            if (Constants.DEBUG) e.printStackTrace();
        }

        return "";
    }


    /**
     * Edit only column 0, the select column.
     *
     * @param row
     * @param col
     * @return true if editable
     */
    @Override public boolean isCellEditable(int row, int col) {
        switch (col) {
            case 0:
            case 1:
            case 2:
                return true;

            default:
                return false;
        }
    }


    /**
     * @param value
     * @param row
     * @param col
     */
    @Override public void setValueAt(Object value, int row, int col) {
        AudioTrack  track = JTagger.get().getMainWindow().getTrackPane().getTrackTable().getTrackModel().getTrack(row);

        try {
            if (track != null) {
                if (col == 0) {
                    track.setSelected((Boolean) value);
                }
                else if (col == 1) {
                    Log.get().addTime(2, String.format("Changing track for file '%s' from '%s' to '%s'", track.aFileName, track.aTrack, value.toString()));
                    track.aTrack = value.toString();
                    track.write(track.aType);
                    JTagger.get().setMessage(Constants.MESSAGE_WRITE_OK, false);
                    JTagger.get().reloadAllTables();
                }
                else if (col == 2) {
                    Log.get().addTime(2, String.format("Changing filename for %s to %s", track.aFileName, (String) value));
                    track.rename((String) value);
                    JTagger.get().setMessage(Constants.MESSAGE_WRITE_OK, false);
                    JTagger.get().reloadAllTables();
                }
            }
        }
        catch (Exception e) {
            Log.get().addTime(1, e.getMessage());
            JTagger.get().setMessage(e.getMessage(), true);
            JTagger.get().reloadAllTables();
        }
    }


    /**
     * Handle mouse lciks on the table header.
     * Do a sort on the column type.
     */
    private class MouseHandler extends MouseAdapter {
        /**
         *
         * @param mouseEvent
         */
        @Override public void mouseClicked(MouseEvent mouseEvent) {
            JTableHeader h = (JTableHeader) mouseEvent.getSource();
            TableColumnModel columnModel = h.getColumnModel();
            int viewColumn = columnModel.getColumnIndexAtX(mouseEvent.getX());
            int column = columnModel.getColumn(viewColumn).getModelIndex();

            if (column != -1) {
                switch (column) {
                    case 0:
                        JTagger.get().getMainWindow().getTrackPane().getTrackTable().getTrackModel().getComparator().aSortType = AudioTrackComparator.SORT.COMPARE_SELECTED;
                        break;

                    case 1:
                        JTagger.get().getMainWindow().getTrackPane().getTrackTable().getTrackModel().getComparator().aSortType = AudioTrackComparator.SORT.COMPARE_TRACK;
                        break;

                    default:
                        JTagger.get().getMainWindow().getTrackPane().getTrackTable().getTrackModel().getComparator().aSortType = AudioTrackComparator.SORT.COMPARE_FILE;
                        break;
                }

                if (mouseEvent.isControlDown()) {
                    JTagger.get().getMainWindow().getTrackPane().getTrackTable().getTrackModel().setSortAscending(false);
                    JTagger.get().getMainWindow().getTrackPane().getTrackTable().getTrackModel().sort();
                }
                else {
                    JTagger.get().getMainWindow().getTrackPane().getTrackTable().getTrackModel().setSortAscending(true);
                    JTagger.get().getMainWindow().getTrackPane().getTrackTable().getTrackModel().sort();
                }
            }
        }
    }
}
